/* acconfig.h
   This file is in the public domain.

   Descriptive text for the C preprocessor macros that
   the distributed Autoconf macros can define.
   No software package will use all of them; autoheader copies the ones
   your configure.in uses into your configuration header file templates.

   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  Although this order
   can split up related entries, it makes it easier to check whether
   a given entry is in the file.

   Leave the following blank line there!!  Autoheader needs it.  */


/* Define if the debug option is enabled. */
#undef DEBUG

#undef HAVE_DB2

#undef HAVE_DB3

#undef LINUX

#undef FREEBSD

#undef NETBSD

#undef OPENBSD

#undef SOLARIS

#undef HPUX
